@@ -10,5 +10,5 @@ for dir in pde examples scripts tests; do
     echo "Formatting files in ${dir}:"
 
     # black format all code
-    black -t py36 ../${dir}
+    black ../${dir}
 done
\ No newline at end of file
